pub struct ReturnPointee<T>(pub T);Expand description
Action that returns the value the Pointee points to when called.
Tuple Fields
0: TTrait Implementations
Sourceimpl<P, T, X> Action<X, T> for ReturnPointee<P>where
P: Pointee<T>,
impl<P, T, X> Action<X, T> for ReturnPointee<P>where
P: Pointee<T>,
Sourceimpl<T: Clone> Clone for ReturnPointee<T>
impl<T: Clone> Clone for ReturnPointee<T>
Sourcefn clone(&self) -> ReturnPointee<T>
fn clone(&self) -> ReturnPointee<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T: Copy> Copy for ReturnPointee<T>
Sourceimpl<T: Debug> Debug for ReturnPointee<T>
impl<T: Debug> Debug for ReturnPointee<T>
impl<T: Eq> Eq for ReturnPointee<T>
Sourceimpl<T: Hash> Hash for ReturnPointee<T>
impl<T: Hash> Hash for ReturnPointee<T>
Sourceimpl<T: Ord> Ord for ReturnPointee<T>
impl<T: Ord> Ord for ReturnPointee<T>
Sourcefn cmp(&self, other: &ReturnPointee<T>) -> Ordering
fn cmp(&self, other: &ReturnPointee<T>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialEq> PartialEq for ReturnPointee<T>
impl<T: PartialEq> PartialEq for ReturnPointee<T>
Sourcefn eq(&self, other: &ReturnPointee<T>) -> bool
fn eq(&self, other: &ReturnPointee<T>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<T: PartialOrd> PartialOrd for ReturnPointee<T>
impl<T: PartialOrd> PartialOrd for ReturnPointee<T>
impl<T> StructuralPartialEq for ReturnPointee<T>