pub fn range<R, T>(range: R) -> Range<R, T>where
R: RangeBounds<T>,Expand description
Creates a new Range matcher that matches if the argument it is in the passed
range.
pub fn range<R, T>(range: R) -> Range<R, T>where
R: RangeBounds<T>,Creates a new Range matcher that matches if the argument it is in the passed
range.