InSequence

Struct InSequence 

pub struct InSequence { /* private fields */ }
Same like Sequence with the different that all expectations that are added after the InSequence has been defined are added to this sequence automatically.

InSequence is thread local.

Implementations

Source

impl InSequence

pub fn new(sequence: &Sequence) -> Self

Create a new InSequence instance that automatically adds expectations to the passed sequence.

pub fn create_handle() -> Option<SequenceHandle>

Returns a new Some(SequenceHandle) for a sequence that was defined by InSequence before. None is returned if no InSequence instance is known in the current context.