pub struct InSequence { /* private fields */ }Expand description
Same like Sequence with the different that all expectations that are added
after the InSequence has been defined are added to this sequence automatically.
InSequence is thread local.
Implementations
Sourceimpl InSequence
impl InSequence
Sourcepub fn new(sequence: &Sequence) -> Self
pub fn new(sequence: &Sequence) -> Self
Create a new InSequence instance that automatically adds expectations
to the passed sequence.
Sourcepub fn create_handle() -> Option<SequenceHandle>
pub fn create_handle() -> Option<SequenceHandle>
Returns a new Some(SequenceHandle) for a sequence that was defined by InSequence
before. None is returned if no InSequence instance is known in the current
context.